diff --git a/IPython/frontend/html/notebook/static/js/maintoolbar.js b/IPython/frontend/html/notebook/static/js/maintoolbar.js
index 72fec92..0ac6b36 100644
--- a/IPython/frontend/html/notebook/static/js/maintoolbar.js
+++ b/IPython/frontend/html/notebook/static/js/maintoolbar.js
@@ -51,10 +51,10 @@ var IPython = (function (IPython) {
                 },
                 {
                     id : 'paste_b',
-                    label : 'Paste Cell Above',
+                    label : 'Paste Cell Below',
                     icon : 'ui-icon-clipboard',
                     callback : function () {
-                        IPython.notebook.paste_cell_above();
+                        IPython.notebook.paste_cell_below();
                         }
                 }
             ],'cut_copy_paste');
diff --git a/IPython/frontend/html/notebook/static/js/notebook.js b/IPython/frontend/html/notebook/static/js/notebook.js
index cb0ec20..e7b9286 100644
--- a/IPython/frontend/html/notebook/static/js/notebook.js
+++ b/IPython/frontend/html/notebook/static/js/notebook.js
@@ -142,8 +142,8 @@ var IPython = (function (IPython) {
                 that.control_key_active = false;
                 return false;
             } else if (event.which === 86 && that.control_key_active) {
-                // Paste above selected cell = v
-                that.paste_cell_above();
+                // Paste below selected cell = v
+                that.paste_cell_below();
                 that.control_key_active = false;
                 return false;
             } else if (event.which === 68 && that.control_key_active) {